@@ -16,7 +16,12 @@
 #' @param ...,class Used to for subclasses.
 #' @keywords internal
 #' @export
-new_factor <- function(x = integer(), levels = character(), ..., class = character()) {
+new_factor <- function(
+  x = integer(),
+  levels = character(),
+  ...,
+  class = character()
+) {
   stopifnot(is.integer(x))
   stopifnot(is.character(levels))
 
@@ -58,7 +63,7 @@ vec_restore.ordered <- function(x, to, ...) {
 
 #' @export
 vec_ptype_full.factor <- function(x, ...) {
-  paste0("factor<", hash_label(levels(x)), ">")
+  paste0("factor<", hash_label(levels(x)), ">", vec_ptype_shape(x))
 }
 
 #' @export
@@ -68,7 +73,7 @@ vec_ptype_abbr.factor <- function(x, ...) {
 
 #' @export
 vec_ptype_full.ordered <- function(x, ...) {
-  paste0("ordered<", hash_label(levels(x)), ">")
+  paste0("ordered<", hash_label(levels(x)), ">", vec_ptype_shape(x))
 }
 
 #' @export
@@ -117,13 +122,14 @@ vec_ptype2.ordered.character <- function(x, y, ...) {
 vec_ptype2.character.ordered <- function(x, y, ...) {
   stop_native_implementation("vec_ptype2.character.ordered")
 }
+
 #' @export
-vec_ptype2.ordered.factor <- function(x, y, ..., x_arg = "", y_arg = "") {
-  stop_incompatible_type(x, y, x_arg = x_arg, y_arg = y_arg)
+vec_ptype2.ordered.factor <- function(x, y, ...) {
+  vec_default_ptype2(x, y, ...)
 }
 #' @export
-vec_ptype2.factor.ordered <- function(x, y, ..., x_arg = "", y_arg = "") {
-  stop_incompatible_type(x, y, x_arg = x_arg, y_arg = y_arg)
+vec_ptype2.factor.ordered <- function(x, y, ...) {
+  vec_default_ptype2(x, y, ...)
 }
 
 
@@ -137,11 +143,19 @@ vec_cast.factor <- function(x, to, ...) {
   UseMethod("vec_cast.factor")
 }
 
-fct_cast <- function(x, to, ..., x_arg = "", to_arg = "") {
-  fct_cast_impl(x, to, ..., x_arg = x_arg, to_arg = to_arg, ordered = FALSE)
+fct_cast <- function(x, to, ..., call = caller_env()) {
+  fct_cast_impl(x, to, ..., ordered = FALSE, call = call)
 }
 
-fct_cast_impl <- function(x, to, ..., x_arg = "", to_arg = "", ordered = FALSE) {
+fct_cast_impl <- function(
+  x,
+  to,
+  ...,
+  x_arg = "",
+  to_arg = "",
+  ordered = FALSE,
+  call = caller_env()
+) {
   if (length(levels(to)) == 0L) {
     levels <- levels(x)
     if (is.null(levels)) {
@@ -150,10 +164,20 @@ fct_cast_impl <- function(x, to, ..., x_arg = "", to_arg = "", ordered = FALSE)
     } else {
       exclude <- NULL
     }
-    factor(as.character(x), levels = levels, ordered = ordered, exclude = exclude)
+    factor(
+      as.character(x),
+      levels = levels,
+      ordered = ordered,
+      exclude = exclude
+    )
   } else {
     lossy <- !(x %in% levels(to) | is.na(x))
-    out <- factor(x, levels = levels(to), ordered = ordered, exclude = NULL)
+    out <- factor(
+      x,
+      levels = levels(to),
+      ordered = ordered,
+      exclude = NULL
+    )
     maybe_lossy_cast(
       out,
       x,
@@ -161,7 +185,8 @@ fct_cast_impl <- function(x, to, ..., x_arg = "", to_arg = "", ordered = FALSE)
       lossy,
       loss_type = "generality",
       x_arg = x_arg,
-      to_arg = to_arg
+      to_arg = to_arg,
+      call = call
     )
   }
 }
@@ -171,7 +196,7 @@ vec_cast.factor.factor <- function(x, to, ...) {
   fct_cast(x, to, ...)
 }
 #' @export
-vec_cast.factor.character <-function(x, to, ...) {
+vec_cast.factor.character <- function(x, to, ...) {
   fct_cast(x, to, ...)
 }
 #' @export
@@ -187,8 +212,8 @@ vec_cast.ordered <- function(x, to, ...) {
   UseMethod("vec_cast.ordered")
 }
 
-ord_cast <- function(x, to, ..., x_arg = "", to_arg = "") {
-  fct_cast_impl(x, to, ..., x_arg = x_arg, to_arg = to_arg, ordered = TRUE)
+ord_cast <- function(x, to, ..., call = caller_env()) {
+  fct_cast_impl(x, to, ..., ordered = TRUE, call = call)
 }
 
 #' @export
@@ -197,7 +222,7 @@ vec_cast.ordered.ordered <- function(x, to, ...) {
 }
 
 #' @export
-vec_cast.ordered.character <-function(x, to, ...) {
+vec_cast.ordered.character <- function(x, to, ...) {
   ord_cast(x, to, ...)
 }
 #' @export
