@@ -4,6 +4,6 @@
 #include "vctrs-core.h"
 
 r_obj* vec_ptype(r_obj* x, struct vctrs_arg* x_arg, struct r_lazy call);
-r_obj* vec_ptype_final(r_obj* x);
+r_obj* vec_ptype_final(r_obj* x, struct vctrs_arg* x_arg, struct r_lazy call);
 
 #endif
