@@ -1,6 +1,9 @@
+// IWYU pragma: private; include "rlang.h"
+
 #ifndef RLANG_DEBUG_H
 #define RLANG_DEBUG_H
 
+#include "rlang-types.h"
 
 #define r_printf Rprintf
 void r_sexp_inspect(r_obj* x);
