@@ -1,4 +1,3 @@
-
 test_that("vec_as_subscript() coerces unspecified vectors", {
   expect_identical(
     vec_as_subscript(NA),
@@ -60,9 +59,18 @@ test_that("can customise subscript errors", {
 
 test_that("vec_as_subscript() checks dimensionality", {
   expect_snapshot({
-    (expect_error(vec_as_subscript(matrix(TRUE, nrow = 1)), class = "vctrs_error_subscript_type"))
-    (expect_error(vec_as_subscript(array(TRUE, dim = c(1, 1, 1))), class = "vctrs_error_subscript_type"))
-    (expect_error(with_tibble_rows(vec_as_subscript(matrix(TRUE, nrow = 1))), class = "vctrs_error_subscript_type"))
+    (expect_error(
+      vec_as_subscript(matrix(TRUE, nrow = 1)),
+      class = "vctrs_error_subscript_type"
+    ))
+    (expect_error(
+      vec_as_subscript(array(TRUE, dim = c(1, 1, 1))),
+      class = "vctrs_error_subscript_type"
+    ))
+    (expect_error(
+      with_tibble_rows(vec_as_subscript(matrix(TRUE, nrow = 1))),
+      class = "vctrs_error_subscript_type"
+    ))
   })
 })
 
@@ -72,12 +80,21 @@ test_that("vec_as_subscript() works with vectors of dimensionality 1", {
 })
 
 test_that("vec_as_subscript() forbids subscript types", {
-  expect_snapshot(error = TRUE, vec_as_subscript(1L, logical = "error", numeric = "error"))
-  expect_snapshot(error = TRUE, vec_as_subscript("foo", logical = "error", character = "error"))
+  expect_snapshot(
+    error = TRUE,
+    vec_as_subscript(1L, logical = "error", numeric = "error")
+  )
+  expect_snapshot(
+    error = TRUE,
+    vec_as_subscript("foo", logical = "error", character = "error")
+  )
   expect_snapshot(error = TRUE, vec_as_subscript(TRUE, logical = "error"))
   expect_snapshot(error = TRUE, vec_as_subscript("foo", character = "error"))
   expect_snapshot(error = TRUE, vec_as_subscript(NULL, numeric = "error"))
-  expect_snapshot(error = TRUE, vec_as_subscript(quote(foo), character = "error"))
+  expect_snapshot(
+    error = TRUE,
+    vec_as_subscript(quote(foo), character = "error")
+  )
 })
 
 test_that("vec_as_subscript2() forbids subscript types", {
@@ -87,7 +104,10 @@ test_that("vec_as_subscript2() forbids subscript types", {
 })
 
 test_that("vec_as_subscript2() retains the call when throwing vec_as_subscript() errors (#1605)", {
-  expect_snapshot(error = TRUE, vec_as_subscript2(1L, numeric = "error", call = call("foo")))
+  expect_snapshot(
+    error = TRUE,
+    vec_as_subscript2(1L, numeric = "error", call = call("foo"))
+  )
   expect_snapshot(error = TRUE, vec_as_subscript2(1.5, call = call("foo")))
 })
 
@@ -97,12 +117,25 @@ test_that("vec_as_subscript2() retains the call when erroring on logical input (
 
 test_that("vec_as_subscript() evaluates arg lazily", {
   expect_silent(vec_as_subscript(1L, arg = print("oof")))
-  expect_silent(vec_as_subscript_result(1L, arg = print("oof"), NULL, logical = "error", numeric = "cast", character = "error"))
+  expect_silent(vec_as_subscript_result(
+    1L,
+    arg = print("oof"),
+    NULL,
+    logical = "error",
+    numeric = "cast",
+    character = "error"
+  ))
 })
 
 test_that("vec_as_subscript2() evaluates arg lazily", {
   expect_silent(vec_as_subscript2(1L, arg = print("oof")))
-  expect_silent(vec_as_subscript2_result(1L, arg = print("oof"), NULL, numeric = "cast", character = "error"))
+  expect_silent(vec_as_subscript2_result(
+    1L,
+    arg = print("oof"),
+    NULL,
+    numeric = "cast",
+    character = "error"
+  ))
 })
 
 test_that("`logical = 'cast'` is deprecated", {
